import type { NetworkAdapter, ResourceRequest } from '@luvio/engine';
import type { JwtManager, JwtToken } from '@luvio/jwt-manager';
export type ModifyResourceRequestHook<T, E> = (resourceRequest: ResourceRequest, jwtToken: JwtToken<T, E>) => ResourceRequest;
/**
 * Adds Authentication for the provided {@link ResourceRequest}
 *
 * @param resourceRequest
 * @param jwt
 * @return
 */
export declare function authenticateRequest<T, E>(resourceRequest: ResourceRequest, jwt: JwtToken<T, E>): ResourceRequest;
/**
 * Wrapper around fetch network adapter from luvio with access to JwtManager {@link JwtManager} to authenticate Request
 * And a hook to update the base URI for the provided {@link ResourceRequest}
 *
 * @param jwtManager: {@link JwtManager}
 * @param modifyResourceRequestHook: {@link ModifyResourceRequestHook}
 * @returns jwtNetworkAdapter {@link NetworkAdapter}
 */
export declare function setupJwtNetworkAdapter<T, E>(jwtManager: JwtManager<T, E>, modifyResourceRequestHook?: ModifyResourceRequestHook<T, E>): NetworkAdapter;
